"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toastReducer = void 0;

var _context = require("./context");

/**
 * Given the current state (toast map) and an action,
 * produce a new state depending on the action.
 * The new map of toasts (id => toast) is immutable.
 *
 * @param state The map of id -> toast connections
 * @param action The required action
 */
var toastReducer = (state, action) => {
  switch (action.type) {
    case _context.ToastActionType.TOAST_CREATE:
      {
        var toastMap = new Map(state);
        toastMap.set(action.id, action.data);
        return toastMap;
      }

    case _context.ToastActionType.TOAST_REMOVE:
      {
        var _toastMap = new Map(state);

        _toastMap.delete(action.id);

        return _toastMap;
      }

    case _context.ToastActionType.TOAST_REMOVE_ALL:
      {
        return new Map();
      }

    default:
      return state;
  }
};

exports.toastReducer = toastReducer;